<?php

namespace Drupal\dxpr_builder\Form;

use Drupal\Core\Url;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Provides a form for DXPR Builder AI Settings.
 */
class DxprBuilderAiSettingsForm extends FormBase {

  /**
   * Configuration Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The module extension list.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleList;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory.
   * @param \Drupal\Core\Extension\ModuleExtensionList $moduleList
   *   The module extension list.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
    ModuleExtensionList $moduleList,
    EntityTypeManagerInterface $entityTypeManager,
  ) {
    $this->configFactory = $configFactory;
    $this->moduleList = $moduleList;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   *
   * @phpstan-return mixed
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('extension.list.module'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dxpr_builder_ai_settings';
  }

  /**
   * {@inheritdoc}
   *
   * @phpstan-param array<string, mixed> $form
   * @phpstan-return array<string, mixed>
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    // Get the configuration.
    $config = $this->configFactory->getEditable('dxpr_builder.settings');
    $ai_enabled = $config->get('ai_enabled') ?? 1;
    $ai_model = $config->get('ai_model') ?: 'dxai_kavya_m1';
    $providers_config = $config->get('ai_providers') ?? [];

    // Add library for draggable tables.
    $form['#attached']['library'][] = 'core/drupal.tableheader';
    $form['#attached']['library'][] = 'core/drupal.tabledrag';
    $form['#attached']['library'][] = 'dxpr_builder/ai-providers';

    // Attach our CSS library.
    $form['#attached']['library'][] = 'dxpr_builder/ai-settings-form';

    // Add a class to the form for targeting.
    $form['#attributes'] = ['class' => ['dxpr-builder-ai-settings-form']];

    $form['#title'] = $this->t('AI settings (beta)');

    // Settings section.
    $form['settings_title'] = [
      '#type' => 'markup',
      '#markup' => '<h2>' . $this->t('Settings') . '</h2>',
    ];

    // Basic settings fieldset.
    $form['basic_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Basic AI Settings'),
      '#open' => TRUE,
    ];

    $form['basic_settings']['ai_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $ai_enabled,
      '#description' => $this->t('Enable AI writing assistant in the text editor.'),
    ];

    $form['basic_settings']['ai_model'] = [
      '#type' => 'select',
      '#title' => $this->t('Model'),
      '#default_value' => $ai_model,
      '#options' => [
        'dxai_kavya_m1' => $this->t('DXAI Kavya M1'),
        'dxai_kavya_m1_eu' => $this->t('DXAI Kavya M1 EU'),
      ],
      '#description' => $this->t('DXAI Kavya M1: Best performance with OpenAI, Google Gemini, and Anthropic. DXAI Kavya M1 EU: Privacy-focused option using MistralAI.'),
    ];

    // Get all vocabularies for the dropdown.
    $vocabulary_options = [];
    $vocabularies = $this->entityTypeManager->getStorage('taxonomy_vocabulary')->loadMultiple();
    foreach ($vocabularies as $vocabulary) {
      $vocabulary_options[$vocabulary->id()] = $vocabulary->label();
    }

    // If no vocabularies exist at all, add a placeholder option.
    if (empty($vocabulary_options)) {
      $vocabulary_options[''] = $this->t('- No vocabularies available -');
    }

    // Tone of voice fieldset (at the same level as other fieldsets)
    $form['tone_of_voice'] = [
      '#type' => 'details',
      '#title' => $this->t('Tone of Voice Settings'),
      '#open' => FALSE,
      '#attributes' => [
        'class' => ['tone-of-voice'],
      ],
      '#description' => $this->t('Configure the tones of voice available to content creators when interacting with the AI Agent.'),
    ];

    $form['tone_of_voice']['info'] = [
      '#markup' => '<p>' . $this->t('Select a vocabulary to manage your tones of voice.') . '</p>',
    ];

    // Get saved tone vocabulary and check if it exists.
    $saved_tone_vocab = $config->get('tone_of_voice_vocabulary');
    $tone_default_value = '';

    if ($saved_tone_vocab && isset($vocabulary_options[$saved_tone_vocab])) {
      $tone_default_value = $saved_tone_vocab;
    }

    $form['tone_of_voice']['tone_of_voice_vocabulary'] = [
      '#type' => 'select',
      '#title' => $this->t('Tone Collection'),
      '#description' => $this->t('Select a vocabulary to manage your tones'),
      '#options' => $vocabulary_options,
      '#default_value' => $tone_default_value,
      '#required' => TRUE,
      '#empty_option' => $this->t('- Select a vocabulary -'),
      '#empty_value' => '',
    ];

    // Create a preview container for tone terms.
    $form['tone_of_voice']['preview_container'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => ['tone-preview-container'],
      ],
    ];

    // Only try to load terms if a vocabulary is selected.
    $selected_tone_vocab = $form_state->getValue(['tone_of_voice', 'tone_of_voice_vocabulary']) ?: $tone_default_value;

    if (!empty($selected_tone_vocab)) {
      try {
        $term_storage = $this->entityTypeManager->getStorage('taxonomy_term');
        $query = $term_storage->getQuery()
          ->condition('vid', $selected_tone_vocab)
          ->condition('status', 1)
          ->sort('weight')
          ->accessCheck(FALSE);
        $tone_tids = $query->execute();

        if (empty($tone_tids)) {
          $form['tone_of_voice']['preview_container']['no_terms'] = [
            '#type' => 'markup',
            '#markup' => $this->t('<div class="messages messages--warning">No tone terms found in the selected vocabulary. Please <a href="@add_link" target="_blank">add some terms</a>.</div>', [
              '@add_link' => Url::fromRoute('entity.taxonomy_term.add_form', [
                'taxonomy_vocabulary' => $selected_tone_vocab,
              ])->toString(),
            ]),
          ];
        }
        else {
          $tone_terms = $term_storage->loadMultiple($tone_tids);

          // Create a table for tone of voice terms.
          $form['tone_of_voice']['preview_container']['terms_table'] = [
            '#type' => 'table',
            '#header' => [
              $this->t('Label'),
              $this->t('Tone'),
            ],
            '#empty' => $this->t('No tone of voice terms found.'),
            '#attributes' => [
              'class' => ['tone-terms-table', 'responsive-enabled'],
              'data-striping' => '1',
              'data-once' => 'tableresponsive',
            ],
          ];

          foreach ($tone_terms as $term) {
            $term_name = $term->getName();
            $term_description = $term->getDescription();

            $form['tone_of_voice']['preview_container']['terms_table'][$term->id()] = [
              'name' => [
                '#markup' => $term_name,
                '#wrapper_attributes' => [
                  'class' => ['tone-name'],
                ],
              ],
              'description' => [
                '#markup' => $term_description,
                '#wrapper_attributes' => [
                  'class' => ['tone-description'],
                ],
              ],
              '#attributes' => [
                'class' => ['tone-row'],
              ],
            ];
          }

          // Add manage link after the table.
          $form['tone_of_voice']['preview_container']['manage_link'] = [
            '#type' => 'container',
            '#attributes' => [
              'class' => ['tone-manage-link'],
            ],
            'link' => [
              '#type' => 'link',
              '#title' => $this->t('Manage Tones'),
              '#url' => Url::fromRoute('entity.taxonomy_vocabulary.overview_form', [
                'taxonomy_vocabulary' => $selected_tone_vocab,
              ]),
              '#attributes' => [
                'class' => ['button'],
              ],
            ],
          ];
        }
      }
      catch (\Exception $e) {
        $this->messenger()->addError($this->t('Error loading tone terms: @error', ['@error' => $e->getMessage()]));
      }
    }
    else {
      $form['tone_of_voice']['preview_container']['no_vocab'] = [
        '#type' => 'markup',
        '#markup' => $this->t('<div class="messages messages--info">Please select a vocabulary to manage tones.</div>'),
      ];
    }

    // Commands fieldset (at the same level as other fieldsets)
    $form['commands'] = [
      '#type' => 'details',
      '#title' => $this->t('AI Edit Commands'),
      '#open' => FALSE,
      '#attributes' => [
        'class' => ['commands'],
      ],
      '#description' => $this->t('Configure the commands available to content creators when interacting with the AI Agent.'),
    ];

    $form['commands']['info'] = [
      '#markup' => '<p>' . $this->t('Select a vocabulary to manage your AI commands.') . '</p>',
    ];

    // Get saved commands vocabulary and check if it exists.
    $saved_commands_vocab = $config->get('commands_vocabulary');
    $commands_default_value = '';

    if ($saved_commands_vocab && isset($vocabulary_options[$saved_commands_vocab])) {
      $commands_default_value = $saved_commands_vocab;
    }

    $form['commands']['commands_vocabulary'] = [
      '#type' => 'select',
      '#title' => $this->t('Command Collection'),
      '#description' => $this->t('Select a vocabulary to manage your commands'),
      '#options' => $vocabulary_options,
      '#default_value' => $commands_default_value,
      '#required' => TRUE,
      '#empty_option' => $this->t('- Select a vocabulary -'),
      '#empty_value' => '',
    ];

    // Create a preview container for command terms.
    $form['commands']['preview_container'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => ['commands-preview-container'],
      ],
    ];

    // Only try to load terms if a vocabulary is selected.
    $selected_commands_vocab = $form_state->getValue(['commands', 'commands_vocabulary']) ?: $commands_default_value;

    if (!empty($selected_commands_vocab)) {
      try {
        $term_storage = $this->entityTypeManager->getStorage('taxonomy_term');

        // First, get all parent terms (categories)
        $parent_query = $term_storage->getQuery()
          ->condition('vid', $selected_commands_vocab)
          ->condition('status', 1)
          ->condition('parent', 0)
          ->sort('weight')
          ->accessCheck(FALSE);
        $parent_tids = $parent_query->execute();

        if (empty($parent_tids)) {
          $form['commands']['preview_container']['no_terms'] = [
            '#type' => 'markup',
            '#markup' => $this->t('<div class="messages messages--warning">No command terms found in the selected vocabulary. Please <a href="@add_link" target="_blank">add some terms</a>.</div>', [
              '@add_link' => Url::fromRoute('entity.taxonomy_term.add_form', [
                'taxonomy_vocabulary' => $selected_commands_vocab,
              ])->toString(),
            ]),
          ];
        }
        else {
          $parent_terms = $term_storage->loadMultiple($parent_tids);

          // Create a table for commands.
          $form['commands']['preview_container']['commands_table'] = [
            '#type' => 'table',
            '#header' => [
              $this->t('Command'),
              $this->t('Instruction'),
            ],
            '#empty' => $this->t('No commands found.'),
            '#attributes' => [
              'class' => ['commands-table', 'responsive-enabled'],
              'data-striping' => '1',
              'data-once' => 'tableresponsive',
            ],
          ];

          $row_index = 0;

          // Process each parent term (category)
          foreach ($parent_terms as $parent_term) {
            $parent_name = $parent_term->getName();

            // Add category header row.
            $form['commands']['preview_container']['commands_table'][$row_index] = [
              'header' => [
                '#markup' => $parent_name . ' (Category)',
                '#wrapper_attributes' => [
                  'colspan' => 2,
                  'class' => ['command-category-header'],
                ],
              ],
              '#attributes' => [
                'class' => ['command-category-row'],
              ],
            ];
            $row_index++;

            // Get child terms for this parent.
            $child_query = $term_storage->getQuery()
              ->condition('vid', $selected_commands_vocab)
              ->condition('parent', $parent_term->id())
              ->condition('status', 1)
              ->sort('weight')
              ->accessCheck(FALSE);
            $child_tids = $child_query->execute();

            if (!empty($child_tids)) {
              $child_terms = $term_storage->loadMultiple($child_tids);

              foreach ($child_terms as $child_term) {
                $command_name = $child_term->getName();
                $command_description = $child_term->getDescription();

                $form['commands']['preview_container']['commands_table'][$row_index] = [
                  'name' => [
                    '#markup' => $command_name,
                    '#wrapper_attributes' => [
                      'class' => ['command-name'],
                    ],
                  ],
                  'description' => [
                    '#markup' => $command_description,
                    '#wrapper_attributes' => [
                      'class' => ['command-description'],
                    ],
                  ],
                  '#attributes' => [
                    'class' => ['command-row'],
                  ],
                ];
                $row_index++;
              }
            }
            else {
              $form['commands']['preview_container']['commands_table'][$row_index] = [
                'empty' => [
                  '#markup' => $this->t('No commands in this category.'),
                  '#wrapper_attributes' => [
                    'colspan' => 2,
                    'class' => ['empty-category'],
                  ],
                ],
                '#attributes' => [
                  'class' => ['command-row'],
                ],
              ];
              $row_index++;
            }
          }

          // Add manage link after the table.
          $form['commands']['preview_container']['manage_link'] = [
            '#type' => 'container',
            '#attributes' => [
              'class' => ['commands-manage-link'],
            ],
            'link' => [
              '#type' => 'link',
              '#title' => $this->t('Manage Commands'),
              '#url' => Url::fromRoute('entity.taxonomy_vocabulary.overview_form', [
                'taxonomy_vocabulary' => $selected_commands_vocab,
              ]),
              '#attributes' => [
                'class' => ['button'],
              ],
            ],
          ];
        }
      }
      catch (\Exception $e) {
        $this->messenger()->addError($this->t('Error loading command terms: @error', ['@error' => $e->getMessage()]));
      }
    }
    else {
      $form['commands']['preview_container']['no_vocab'] = [
        '#type' => 'markup',
        '#markup' => $this->t('<div class="messages messages--info">Please select a vocabulary to manage commands.</div>'),
      ];
    }

    // AI Providers section (only visible for the standard model)
    $form['ai_providers_wrapper'] = [
      '#type' => 'details',
      '#title' => $this->t('AI Service Providers'),
      '#open' => FALSE,
      '#states' => [
        'visible' => [
          ':input[name="basic_settings[ai_model]"]' => ['value' => 'dxai_kavya_m1'],
        ],
      ],
    ];

    $form['ai_providers_wrapper']['description'] = [
      '#markup' => '<p>' . $this->t('Prioritize AI services by dragging them up or down. The top provider is used first.') . '</p>',
    ];

    // Add explanation about the primary provider.
    $form['ai_providers_wrapper']['primary_provider_info'] = [
      '#markup' => '<div class="region-help-text">' . $this->t('Requests automatically fall back to the next enabled provider depending on availability and response times.') . '</div>',
    ];

    // Get the module path for images.
    $module_path = $this->moduleList->getPath('dxpr_builder');

    // Provider information with logos and descriptions.
    $provider_info = [
      'anthropic' => [
        'label' => $this->t('Anthropic'),
        'logo' => '/' . $module_path . '/dxpr_builder/images-backend/ai/anthropic-logo.svg',
      ],
      'gemini' => [
        'label' => $this->t('Google Gemini'),
        'logo' => '/' . $module_path . '/dxpr_builder/images-backend/ai/gemini-logo.svg',
      ],
      'mistralai' => [
        'label' => $this->t('MistralAI'),
        'logo' => '/' . $module_path . '/dxpr_builder/images-backend/ai/mistralai-logo.svg',
      ],
      'openai' => [
        'label' => $this->t('OpenAI'),
        'logo' => '/' . $module_path . '/dxpr_builder/images-backend/ai/openai-logo.svg',
      ],
      'xai' => [
        'label' => $this->t('XAI'),
        'logo' => '/' . $module_path . '/dxpr_builder/images-backend/ai/xai-logo.svg',
      ],
    ];

    // Create the table - place it inside the conditional wrapper.
    $form['ai_providers_wrapper']['providers'] = [
      '#type' => 'table',
      '#header' => [
        $this->t('Providers fallback order'),
        ['data' => $this->t('Weight'), 'class' => ['tabledrag-hide']],
        ['data' => '', 'class' => ['tabledrag-hide']],
      ],
      '#empty' => $this->t('No providers available.'),
      '#tabledrag' => [
        [
          'action' => 'order',
          'relationship' => 'sibling',
          'group' => 'field-weight',
        ],
        [
          'action' => 'match',
          'relationship' => 'parent',
          'group' => 'provider-region-name',
          'hidden' => TRUE,
          'source' => 'region-name',
        ],
      ],
      '#attributes' => [
        'id' => 'field-display-overview',
        'class' => ['field-ui-overview', 'responsive-enabled', 'draggable-table'],
      ],
      // Ensure empty cells are rendered.
      '#empty_cell_value' => '',
      // Ensure all cells get rendered.
      '#sticky' => FALSE,
    ];

    // Add region rows.
    $regions = [
      'enabled' => [
        'title' => $this->t('Enabled'),
        'message' => $this->t('No provider is enabled.'),
      ],
      'disabled' => [
        'title' => $this->t('Disabled'),
        'message' => $this->t('No provider is disabled.'),
      ],
    ];

    // Add region rows.
    foreach ($regions as $region => $region_info) {
      // Add region title.
      $form['ai_providers_wrapper']['providers']['region-' . $region] = [
        '#attributes' => [
          'class' => ['region-title', 'region-' . $region . '-title'],
        ],
        'title' => [
          '#markup' => $region_info['title'],
          '#wrapper_attributes' => ['colspan' => 3, 'class' => ['tabledrag-has-colspan']],
        ],
      ];

      // Add region message row.
      $form['ai_providers_wrapper']['providers']['region-' . $region . '-message'] = [
        '#attributes' => [
          'class' => ['region-message', 'region-' . $region . '-message', 'region-empty'],
        ],
        'message' => [
          '#markup' => $region_info['message'],
          '#wrapper_attributes' => ['colspan' => 3, 'class' => ['tabledrag-has-colspan']],
        ],
      ];
    }

    // Prepare sorted providers.
    $sorted_providers = [];

    // Define default weights for providers when no configuration exists.
    $default_weights = [
      'openai' => 0,
      'gemini' => 1,
      'mistralai' => 2,
      'anthropic' => 3,
      'xai' => 4,
    ];

    foreach ($provider_info as $provider_id => $provider) {
      // Get provider configuration or use defaults.
      $provider_config = $providers_config[$provider_id] ?? [
        'enabled' => TRUE,
        'weight' => $default_weights[$provider_id] ?? count($sorted_providers),
        'region' => 'enabled',
      ];

      // Force all providers to be enabled by default if no configuration
      // exists.
      if (!isset($providers_config[$provider_id])) {
        $provider_config['region'] = 'enabled';
      }

      // Add provider data to the sorted list.
      $sorted_providers[$provider_id] = [
        'label' => $provider['label'],
        'logo' => $provider['logo'],
        'weight' => $provider_config['weight'],
        'region' => $provider_config['region'],
      ];
    }

    // Sort by weight.
    uasort($sorted_providers, function ($a, $b) {
      return $b['weight'] <=> $a['weight'];
    });

    // Add provider rows in sorted order.
    foreach ($sorted_providers as $provider_id => $provider) {
      // Create the table row.
      $row = $this->buildProviderRow(
        $provider_id,
        $provider,
        $provider['region'],
        $provider['weight']
      );
      $form['ai_providers_wrapper']['providers'][$provider_id] = $row;
    }

    // Add the "Show row weights" link.
    $form['ai_providers_wrapper']['providers']['#attached']['library'][] = 'core/drupal.tabledrag';
    $form['ai_providers_wrapper']['providers']['#attached']['library'][] = 'core/drupal.tableheader';
    $form['ai_providers_wrapper']['providers']['#attached']['library'][] = 'core/drupal.form';

    // Beta notice and capabilities - Moved to bottom.
    $form['beta_notice'] = [
      '#type' => 'markup',
      '#markup' => '<div class="messages messages--warning">
        <h4>' . $this->t('AI Capabilities (Beta)') . '</h4>
        <p>' . $this->t('AI writing assistant enhances text editing in CKEditor.') . '</p>
        <p>' . $this->t('Coming soon: AI-powered layout creation and landing page building.') . '</p>
        <p class="beta-disclaimer">' . $this->t('Features in testing may have limited availability. EU model performance depends on MistralAI service capacity.') . '</p>
        </div>',
    ];

    $form['actions'] = [
      '#type' => 'actions',
      '#weight' => 99,
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    // Add JavaScript to update links when vocabulary selection changes.
    $form['#attached']['library'][] = 'dxpr_builder/ai-settings-form';

    return $form;
  }

  /**
   * {@inheritdoc}
   *
   * @phpstan-param array<string, mixed> $form
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->configFactory->getEditable('dxpr_builder.settings');
    $values = $form_state->getValues();

    // Save AI settings.
    $config
      ->set('ai_enabled', (bool) $values['ai_enabled'])
      ->set('ai_model', $values['ai_model']);

    // Save tone of voice vocabulary - only if a valid value is selected.
    if (!empty($values['tone_of_voice_vocabulary'])) {
      $config->set('tone_of_voice_vocabulary', $values['tone_of_voice_vocabulary']);
      // Always enable taxonomy tones when a vocabulary is selected.
      $config->set('enable_taxonomy_tones', TRUE);
    }

    // Save commands vocabulary - only if a valid value is selected.
    if (!empty($values['commands_vocabulary'])) {
      $config->set('commands_vocabulary', $values['commands_vocabulary']);
      // Always enable taxonomy commands when a vocabulary is selected.
      $config->set('enable_taxonomy_commands', TRUE);
    }

    // Save provider configuration.
    $providers = [];
    if (isset($values['providers'])) {
      foreach ($values['providers'] as $provider_id => $provider_data) {
        // Skip non-provider rows (like region titles)
        if (!isset($provider_data['region-name'])) {
          continue;
        }

        $region = $provider_data['region-name'];

        // Ensure we're getting a valid region value.
        if (empty($region)) {
          // Default to enabled if no region is specified.
          $region = 'enabled';
        }

        $providers[$provider_id] = [
          'enabled' => $region === 'enabled',
          'weight' => (int) $provider_data['weight'],
          'region' => $region,
        ];
      }

      $config->set('ai_providers', $providers);
    }

    $config->save();

    // Invalidate relevant caches.
    Cache::invalidateTags(['config:dxpr_builder.settings']);

    $this->messenger()->addStatus($this->t('AI settings have been saved.'));
  }

  /**
   * Returns the region to which a provider row is assigned.
   *
   * @param array<string, mixed> $row
   *   The provider row element.
   *
   * @return string
   *   The region name.
   */
  public function getProviderRegion(array $row): string {
    return $row['region-name']['#default_value'];
  }

  /**
   * {@inheritdoc}
   *
   * @param array<string, mixed> $form
   *   The form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    parent::validateForm($form, $form_state);

    // Ensure all providers have a valid region.
    $values = $form_state->getValues();
    if (isset($values['providers'])) {
      foreach ($values['providers'] as $provider_id => $provider_data) {
        // Skip non-provider rows (like region titles)
        if (!isset($provider_data['region-name'])) {
          continue;
        }

        // If region is empty, set it to 'enabled' by default.
        if (empty($provider_data['region-name'])) {
          $form_state->setValue(['providers', $provider_id, 'region-name'], 'enabled');
        }
      }
    }
  }

  /**
   * Builds a provider row for the form table.
   *
   * @param string $provider_id
   *   The provider ID.
   * @param array<string, mixed> $provider
   *   The provider configuration.
   * @param string $region
   *   The region for this provider.
   * @param int $weight
   *   The weight for this provider.
   *
   * @return array<string, mixed>
   *   The form row structure.
   */
  protected function buildProviderRow(string $provider_id, array $provider, string $region, int $weight): array {
    // Build the row.
    $row = [
      '#attributes' => [
        'class' => ['draggable', 'tabledrag-leaf'],
        'data-provider-id' => $provider_id,
        'id' => $provider_id,
      ],

      // Provider logo/label.
      'label' => [
        '#type' => 'markup',
        '#markup' => '<div class="provider-label">
          <div class="provider-logo"><img src="' . $provider['logo'] . '" alt="' . $provider['label'] . '" class="provider-logo-img" width="150">
          <span class="primary-provider-badge">' . $this->t('Primary Provider') . '</span>
          
          </div>
        </div>',
        '#wrapper_attributes' => ['class' => ['tabledrag-cell']],
      ],

      // Weight (for dragging)
      'weight' => [
        '#type' => 'textfield',
        '#title' => $this->t('Weight for @provider', ['@provider' => $provider['label']]),
        '#title_display' => 'invisible',
        '#default_value' => $weight,
        '#size' => 3,
        '#attributes' => ['class' => ['field-weight']],
        '#parents' => ['providers', $provider_id, 'weight'],
        '#wrapper_attributes' => ['class' => ['tabledrag-hide']],
      ],

      // Region name (hidden field) - rendered as a separate cell.
      'region-name-cell' => [
        '#wrapper_attributes' => ['class' => ['region-select-cell', 'tabledrag-hide']],
        'region-name' => [
          '#type' => 'hidden',
          '#default_value' => $region,
          '#attributes' => [
            'class' => ['provider-region-name'],
            'data-drupal-field-parents' => 'providers[' . $provider_id . '][region-name]',
          ],
          '#parents' => ['providers', $provider_id, 'region-name'],
        ],
      ],
    ];

    return $row;
  }

  /**
   * Submit handler for updating tone vocabulary.
   *
   * @param array<string, mixed> $form
   *   The form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function updateToneVocabulary(array &$form, FormStateInterface $form_state): void {
    // Store the selected vocabulary in temporary storage.
    $selected_vocabulary = $form_state->getValue(['tone_of_voice', 'tone_of_voice_vocabulary']);
    if ($selected_vocabulary) {
      // Get the vocabulary name.
      try {
        $vocabulary = $this->entityTypeManager->getStorage('taxonomy_vocabulary')->load($selected_vocabulary);
        $vocabulary_name = $vocabulary ? $vocabulary->label() : $selected_vocabulary;
        $this->messenger()->addStatus($this->t('Tone vocabulary updated to: @vocabulary', [
          '@vocabulary' => $vocabulary_name,
        ]));
      }
      catch (\Exception $e) {
        $this->messenger()->addStatus($this->t('Tone vocabulary updated to: @vocabulary', [
          '@vocabulary' => $selected_vocabulary,
        ]));
      }
    }

    // Set the form to rebuild.
    $form_state->setRebuild();
  }

  /**
   * Submit handler for updating commands vocabulary.
   *
   * @param array<string, mixed> $form
   *   The form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function updateCommandsVocabulary(array &$form, FormStateInterface $form_state): void {
    // Store the selected vocabulary in temporary storage.
    $selected_vocabulary = $form_state->getValue(['commands', 'commands_vocabulary']);
    if ($selected_vocabulary) {
      // Get the vocabulary name.
      try {
        $vocabulary = $this->entityTypeManager->getStorage('taxonomy_vocabulary')->load($selected_vocabulary);
        $vocabulary_name = $vocabulary ? $vocabulary->label() : $selected_vocabulary;
        $this->messenger()->addStatus($this->t('Commands vocabulary updated to: @vocabulary', [
          '@vocabulary' => $vocabulary_name,
        ]));
      }
      catch (\Exception $e) {
        $this->messenger()->addStatus($this->t('Commands vocabulary updated to: @vocabulary', [
          '@vocabulary' => $selected_vocabulary,
        ]));
      }
    }

    // Set the form to rebuild.
    $form_state->setRebuild();
  }

}
